@@ -49,6 +49,7 @@
 
 #include <cassert>
 #include <cstdlib>
+#include <kwidgetsaddons_version.h>
 
 QAction *KWalletEditor::_newFolderAction = nullptr;
 QAction *KWalletEditor::_deleteFolderAction = nullptr;
@@ -388,7 +389,7 @@ void KWalletEditor::deleteFolder()
             if (rc == KMessageBox::Continue) {
                 bool rc = _w->removeFolder(fi->name());
                 if (!rc) {
-                    KMessageBox::sorry(this, i18n("Error deleting folder."));
+                    KMessageBox::error(this, i18n("Error deleting folder."));
                     return;
                 }
                 _currentFolder.clear();
@@ -417,8 +418,20 @@ void KWalletEditor::createFolder()
             }
 
             if (_entryList->existsFolder(n)) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                int rc = KMessageBox::questionTwoActions(this,
+                                                         i18n("Sorry, that folder name is in use. Try again?"),
+                                                         QString(),
+                                                         KGuiItem(i18n("Try Again")),
+                                                         KGuiItem(i18n("Do Not Try")));
+#else
                 int rc = KMessageBox::questionYesNo(this, i18n("Sorry, that folder name is in use. Try again?"), QString(), KGuiItem(i18n("Try Again")), KGuiItem(i18n("Do Not Try")));
+#endif
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                if (rc == KMessageBox::ButtonCode::PrimaryAction) {
+#else
                 if (rc == KMessageBox::Yes) {
+#endif
                     continue;
                 }
                 n.clear();
@@ -456,7 +469,7 @@ void KWalletEditor::saveEntry()
         }
     }
 
-    KMessageBox::sorry(this, i18n("Error saving entry. Error code: %1", rc));
+    KMessageBox::error(this, i18n("Error saving entry. Error code: %1", rc));
 }
 
 void KWalletEditor::restoreEntry()
@@ -476,8 +489,17 @@ void KWalletEditor::entrySelectionChanged(QTreeWidgetItem *item)
 {
     // do not forget to save changes
     if (_saveChanges->isEnabled() && _displayedItem && (_displayedItem != item)) {
-        if (KMessageBox::Yes ==  KMessageBox::questionYesNo(this,
-                i18n("The contents of the current item has changed.\nDo you want to save changes?"))) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (KMessageBox::ButtonCode::PrimaryAction
+            == KMessageBox::questionTwoActions(this,
+#else
+        if (KMessageBox::Yes
+            == KMessageBox::questionYesNo(this,
+#endif
+                                               i18n("The contents of the current item has changed.\nDo you want to save changes?"),
+                                               {},
+                                               KStandardGuiItem::save(),
+                                               KStandardGuiItem::cancel())) {
             saveEntry();
         } else {
             _saveChanges->setEnabled(false);
@@ -774,8 +796,20 @@ void KWalletEditor::newEntry()
 
         // FIXME: prohibits the use of the subheadings
         if (fi->contains(n)) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            int rc = KMessageBox::questionTwoActions(this,
+                                                     i18n("Sorry, that entry already exists. Try again?"),
+                                                     QString(),
+                                                     KGuiItem(i18n("Try Again")),
+                                                     KGuiItem(i18n("Do Not Try")));
+#else
             int rc = KMessageBox::questionYesNo(this, i18n("Sorry, that entry already exists. Try again?"), QString(), KGuiItem(i18n("Try Again")), KGuiItem(i18n("Do Not Try")));
+#endif
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (rc == KMessageBox::ButtonCode::PrimaryAction) {
+#else
             if (rc == KMessageBox::Yes) {
+#endif
                 continue;
             }
             n.clear();
@@ -904,7 +938,7 @@ void KWalletEditor::walletOpened(bool success)
         _entryList->setWallet(_w);
     } else {
         if (!_newWallet) {
-            KMessageBox::sorry(this, i18n("Unable to open the requested wallet."));
+            KMessageBox::error(this, i18n("Unable to open the requested wallet."));
         }
     }
 }
@@ -940,14 +974,14 @@ void KWalletEditor::importWallet()
 
     QTemporaryFile tmpFile;
     if (!tmpFile.open()) {
-        KMessageBox::sorry(this, i18n("Unable to create temporary file for downloading '<b>%1</b>'.", url.toDisplayString()));
+        KMessageBox::error(this, i18n("Unable to create temporary file for downloading '<b>%1</b>'.", url.toDisplayString()));
         return;
     }
 
     KIO::StoredTransferJob *job = KIO::storedGet(url);
     KJobWidgets::setWindow(job, this);
     if (!job->exec()) {
-        KMessageBox::sorry(this, i18n("Unable to access wallet '<b>%1</b>'.", url.toDisplayString()));
+        KMessageBox::error(this, i18n("Unable to access wallet '<b>%1</b>'.", url.toDisplayString()));
         return;
     }
     tmpFile.write(job->data());
@@ -1082,19 +1116,19 @@ void KWalletEditor::importXML()
     KIO::StoredTransferJob *job = KIO::storedGet(url);
     KJobWidgets::setWindow(job, this);
     if (!job->exec()) {
-        KMessageBox::sorry(this, i18n("Unable to access XML file '<b>%1</b>'.", url.toDisplayString()));
+        KMessageBox::error(this, i18n("Unable to access XML file '<b>%1</b>'.", url.toDisplayString()));
         return;
     }
 
     QDomDocument doc;
     if (!doc.setContent(job->data())) {
-        KMessageBox::sorry(this, i18n("Error reading XML file '<b>%1</b>' for input.", url.toDisplayString()));
+        KMessageBox::error(this, i18n("Error reading XML file '<b>%1</b>' for input.", url.toDisplayString()));
         return;
     }
 
     QDomElement top = doc.documentElement();
     if (top.tagName().toLower() != QLatin1String("wallet")) {
-        KMessageBox::sorry(this, i18n("Error: XML file does not contain a wallet."));
+        KMessageBox::error(this, i18n("Error: XML file does not contain a wallet."));
         return;
     }
 
@@ -1245,7 +1279,7 @@ void KWalletEditor::exportXML()
     KIO::StoredTransferJob *putJob = KIO::storedPut(&tf, url, -1);
     KJobWidgets::setWindow(putJob, this);
     if (!putJob->exec()) {
-        KMessageBox::sorry(this, i18n("Unable to store to '<b>%1</b>'.", url.toDisplayString()));
+        KMessageBox::error(this, i18n("Unable to store to '<b>%1</b>'.", url.toDisplayString()));
     }
 }
 
